==> dianna-1.1.0.tar.gz: dianna-1.1.0/tests/test_visualization.py <==
from pathlib import Path
import numpy as np
import pytest
from dianna.visualization import plot_timeseries


def test_plot_timeseries_univariate(tmpdir, random):
    """Test plot univariate time series."""
    x = np.linspace(0, 10, 20)
    y = np.sin(x)
    segments = get_test_segments(data=np.expand_dims(y, 0))

    output_path = Path(tmpdir) / 'temp_visualization_test_univariate.png'

    plot_timeseries(x=x,
                    y=y,
                    segments=segments,
                    show_plot=False,
                    output_filename=output_path)

    assert output_path.exists()


def test_plot_timeseries_multivariate(tmpdir, random):
    """Test plot multivariate time series."""
    x = np.linspace(start=0, stop=10, num=20)
    ys = np.stack((np.sin(x), np.cos(x), np.tan(0.4 * x)))
    segments = get_test_segments(data=ys)
    output_path = Path(tmpdir) / 'temp_visualization_test_multivariate.png'

    plot_timeseries(x=x,
                    y=ys.T,
                    segments=segments,
                    show_plot=False,
                    output_filename=output_path)

    assert output_path.exists()


def get_test_segments(data):
    """Creates some segments for testing the timeseries visualization."""
    n_channels = data.shape[0]
    n_steps = data.shape[1]
    factor = 2
    n_segments = n_steps // factor

    segments = []
    for i_segment in range(n_segments):
        for i_channel in range(n_channels):
            segment = {
                'index': i_segment + i_channel * n_segments,
                'start': i_segment,
                'stop': i_segment + 1,
                'weight': data[i_channel, factor * i_segment],
            }
            if n_channels > 1:
                segment['channel'] = i_channel
            segments.append(segment)

    return segments


@pytest.fixture
def random():
    """Set the random seed."""
    np.random.seed(0)

==> dianna-1.4.0.tar.gz: dianna-1.4.0/tests/test_visualization.py <==
"""Unit tests for visualization modules."""
from pathlib import Path
import numpy as np
import pytest
from dianna.visualization import plot_tabular
from dianna.visualization import plot_timeseries


def test_plot_tabular(tmpdir):
    """Test plot tabular data."""
    x = np.linspace(-5, 5, 3)
    y = [f"Feature {i}" for i in range(len(x))]
    output_path = Path(tmpdir) / "temp_visualization_test_tabular.png"

    plot_tabular(x=x, y=y, show_plot=False, output_filename=output_path)

    assert output_path.exists()


def test_plot_timeseries_univariate(tmpdir, random):
    """Test plot univariate time series."""
    x = np.linspace(0, 10, 20)
    y = np.sin(x)
    segments = get_test_segments(data=np.expand_dims(y, 0))

    output_path = Path(tmpdir) / "temp_visualization_test_univariate.png"

    plot_timeseries(x=x,
                    y=y,
                    segments=segments,
                    show_plot=False,
                    output_filename=output_path)

    assert output_path.exists()


def test_plot_timeseries_multivariate(tmpdir, random):
    """Test plot multivariate time series."""
    x = np.linspace(start=0, stop=10, num=20)
    ys = np.stack((np.sin(x), np.cos(x), np.tan(0.4 * x)))
    segments = get_test_segments(data=ys)
    output_path = Path(tmpdir) / "temp_visualization_test_multivariate.png"

    plot_timeseries(x=x,
                    y=ys.T,
                    segments=segments,
                    show_plot=False,
                    output_filename=output_path)

    assert output_path.exists()


def get_test_segments(data):
    """Creates some segments for testing the timeseries visualization."""
    n_channels = data.shape[0]
    n_steps = data.shape[1]
    factor = 2
    n_segments = n_steps // factor

    segments = []
    for i_segment in range(n_segments):
        for i_channel in range(n_channels):
            segment = {
                "index": i_segment + i_channel * n_segments,
                "start": i_segment,
                "stop": i_segment + 1,
                "weight": data[i_channel, factor * i_segment],
            }
            if n_channels > 1:
                segment["channel"] = i_channel
            segments.append(segment)

    return segments


@pytest.fixture
def random():
    """Set the random seed."""
    np.random.seed(0)
